' ReadLog.vbs
' Lists the log entries in the specified log file
' created since the last time this script read this file.
' Created       2005-10-07
' Last modified 2008-09-18
' Version 0.1.1.0
' Written by Stephen Tuggy
' For Microsoft Windows Scripting Host 5.6
' Using Notepad++ and Microsoft Windows Notepad

' Copyright  2008 Stephen Tuggy
' 
' This program is free software: you can redistribute it and/or modify it
' under the terms of the GNU General Public License as published by the Free
' Software Foundation, either version 3 of the License, or (at your option)
' any later version.
' 
' This program is distributed in the hope that it will be useful, but WITHOUT
' ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
' FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
' more details.
' 
' You should have received a copy of the GNU General Public License along
' with this program.  If not, see <http://www.gnu.org/licenses/>.

' All variables in this script must be declared before use.
Option Explicit

' Define constants for this script.
Const ForReading = 1, ForWriting = 2, ForAppending = 8
Const TristateUseDefault = -2, TristateTrue = -1, TristateFalse = 0
Const BookmarkFileName = "ReadLog.ini"

' Declare variables for this script.
Dim wshl, args, fso, LogFile, LogFileStream, BookmarkFileStream
Dim strLogFilePath, strBookmarkFilePath, strBookmarkLinePrefix
Dim lngLastPos, lngFileSize, strOneLine

' Initialize the variables that need initializing at this point.
Set wshl = CreateObject("WScript.Shell")
Set args = WScript.Arguments
Set fso = CreateObject("Scripting.FileSystemObject")

' Get the path to the log file to read.
If args.Count >= 1 Then
    strLogFilePath = args(0)
Else
    strLogFilePath = InputBox("Please enter the full path and filename" _
        & " of the log file to read:", WScript.ScriptName)
    If strLogFilePath = "" Then
        WScript.Quit(1)                ' User chose Cancel?
    End If
End If

Set LogFile = fso.GetFile(strLogFilePath)

' Find where we left off reading this file last, if applicable.
lngLastPos = 0
strBookmarkFilePath = fso.BuildPath(wshl.SpecialFolders("MyDocuments"), _
        BookmarkFileName)
Set BookmarkFileStream = fso.OpenTextFile(strBookmarkFilePath, _
        ForReading, True, TristateUseDefault)
strBookmarkLinePrefix = """" & LogFile.Path & """ = "
Do Until BookmarkFileStream.AtEndOfStream
    strOneLine = BookmarkFileStream.ReadLine
    If Left(strOneLine, Len(strBookmarkLinePrefix)) = _
            strBookmarkLinePrefix Then
        lngLastPos = CLng(Mid(strOneLine, _
                Len(strBookmarkLinePrefix) + 1))
    End If
Loop
BookmarkFileStream.Close

' If the file is smaller than it was last time,
' assume it's completely different, and start at the beginning.
lngFileSize = LogFile.Size
Set LogFileStream = LogFile.OpenAsTextStream(ForReading, TristateFalse)
If lngFileSize < lngLastPos Then

' Otherwise, start where we left off last time.
Else
    LogFileStream.Skip lngLastPos
End If

' Read each remaining line in the file, and display it on the screen.
Do Until LogFileStream.AtEndOfStream
    strOneLine = LogFileStream.ReadLine
    WScript.Echo strOneLine
Loop
LogFileStream.Close

' At the end of the file, save our place for later.
Set BookmarkFileStream = fso.OpenTextFile(strBookmarkFilePath, _
        ForAppending, True, TristateUseDefault)
strOneLine = strBookmarkLinePrefix & CStr(lngFileSize)
BookmarkFileStream.WriteLine strOneLine
BookmarkFileStream.Close
